@@ -98,7 +98,7 @@ class JustpyCore {
      * @param window
      * @param {number} page_id - id of the page
      * @param title - title of the document
-     * @param {boolean} use_websockets
+     * @param {boolean} use_websockets - If true use web sockets for communication otherwise ajax is used
      * @param redirect
      * @param display_url
      * @param page_ready
@@ -156,33 +156,10 @@ class JustpyCore {
         } else {
             this.setupNoWebSocket();
         }
-        this.createApp1();
-        this.registerAllEvents()
-    }
-
-    /**
-     * create the global app1 Vue object
-     */
-    createApp1() {
-        app1 = new Vue({
-            el: '#components',
-            data: {
-                justpyComponents: justpyComponents
-            },
-            render: function (h) {
-                var comps = [];
-                for (var i = 0; i < this.justpyComponents.length; i++) {
-                    if (this.justpyComponents[i].show) {
-                        comps.push(h(this.justpyComponents[i].vue_type, {
-                            props: {
-                                jp_props: this.justpyComponents[i]
-                            }
-                        }))
-                    }
-                }
-                return h('div', {}, comps);
-            }
-        });
+       app1 = createApp();
+      this.registerAllEvents();
+      
+      
     }
 
     /**
@@ -483,4 +460,4 @@ class JustpyCore {
             send_to_server(e, 'page_event', false);
         });
     }
-}
\ No newline at end of file
+}
